.. _tensor-array:

N-dim array
===========

.. automodule:: diofant.tensor.array

Classes
-------

.. class:: Array
    :module: diofant.tensor.array

    alias of :class:`~diofant.tensor.array.ImmutableDenseNDimArray`

.. autoclass:: ImmutableDenseNDimArray
   :members:

.. autoclass:: ImmutableSparseNDimArray
   :members:

.. autoclass:: MutableDenseNDimArray
   :members:

.. autoclass:: MutableSparseNDimArray
   :members:


Functions
---------

.. autofunction:: derive_by_array

.. autofunction:: permutedims

.. autofunction:: tensorcontraction

.. autofunction:: tensorproduct
